#! /bin/bash
# Copyright 1999-2008, Intel(R) Corporation, All Rights Reserved
# This script uninstalls Intel(R) compilers and related packages.


#Check if the USER is root
IS_USER_ROOT ()
{
   VPRINT "IS_USER_ROOT()"
   if [ "${USER}x" != "rootx" ] ; then
       if [ ! -w /dev ] ; then
            ROOT_USER=0
       else
            ROOT_USER=1
       fi
   else
          ROOT_USER=1
   fi
}

## Check whether RPM is present or not.
IS_RPM_PRESENT ()
{
    VPRINT "IS_RPM_PRESENT()"
    #Check if we can get a shared lock on rpm database
    rpm -q rpm &> /dev/null
    RPM_NOT_FOUND=$?
}


# Figure out the location of intel_sdp_products database.
GET_FLATFILE_DB_LOCATION ()
{
    VPRINT "GET_FLATFILE_DB_LOCATION()"
    if [ "$ROOT_USER" = 1 ]; then
         DB_DIR_PREFIX="/opt/intel"
    else
         DB_DIR_PREFIX=""
         DB_DIR_PREFIX="$(echo ~)/intel"
         if [ "$DB_DIR_PREFIX" = "/root" ] || [ "$DB_DIR_PREFIX" = "/" ] || [ "$DB_DIR_PREFIX" = "" ] || [ "$DB_DIR_PREFIX" = "/intel" ]; then
             DB_DIR_PREFIX="/opt/intel"
         fi
    fi

    if [ "$INTEL_SDP_PRODUCTS_DB" = "" ]; then
           INTEL_SDP_PRODUCTS_DB="$DB_DIR_PREFIX/intel_sdp_products.db"
    fi
}

# Check if starting uninstall from inside the uninstall directory
CHECK_LOCAL_UNINSTALL ()
{
    VPRINT "CHECK_LOCAL_UNINSTALL()"
    CMD="$0"
    DIRNAME_CMD="$(dirname $0)"
    if [ "$DIRNAME_CMD" = "" ] || [ "$DIRNAME_CMD" = "." ] || [ "$DIRNAME_CMD" = "./" ]; then
	# error - start the program outside of the product directory
        echo "$UNS_STRING_1"
	exit 1
    fi
}

# remove cproc rpm
UNINSTALL_CPROC_RPM_AND_ITS_DEPENDENCIES ()
{
    VPRINT "UNINSTALL_CPROC_RPM_AND_ITS_DEPENDENCIES()"
    local RESULT1="$(rpm -qa  | egrep -e 'intel-cproc' | egrep -i $PKGNUM | egrep -e 'mkl' -e 'tbb' -e 'ipp')"
    VPRINT "Cpro C/C++ RPM check for mkl/tbb/ipp installs - RESULT1=<$RESULT1>"
    if [ -n "$RESULT1" ]; then
	# error - cannot remove c/c++ until dependent product components are removed first
	    local THIS_RPM_ARCH=$(rpm -q --queryformat %{ARCH} $CHOSEN_RPM)
	    local THIS_OTHER_RPM_ARCH=""
	    for THIS_OTHER_RPM in $RESULT1
	    do
            THIS_OTHER_RPM_ARCH=$(rpm -q --queryformat %{ARCH} $THIS_OTHER_RPM)
	        if [ "$THIS_OTHER_RPM_ARCH" = "$THIS_RPM_ARCH" ]; then    
                echo "$UNS_STRING_2"
	            read CONTINUE
                RETURN_VAL=1
                return
            fi
        done             
    fi
    local RESULT1="$(rpm -qa | egrep -e 'intel-cprof' | egrep -i $PKGNUM | egrep -v -e 'mkl' -e 'idb')"
    if [ -n "$RESULT1" ]; then
        DO_PRESERVE_FORTRAN RPM
        rpm "$USER_ARGUMENTS" "$CHOSEN_RPM"
        DO_RESTORE_FORTRAN RPM
    else
        #UNINSTALL_DOC_LINKS
        rpm "$USER_ARGUMENTS" "$CHOSEN_RPM"
        RETURN_VAL=$?
    fi
}

# remove cprof rpm
UNINSTALL_CPROF_RPM_AND_ITS_DEPENDENCIES ()
{
    VPRINT "UNINSTALL_CPROF_RPM_AND_ITS_DEPENDENCIES()"
    local RESULT1="$(rpm -qa  | egrep -e 'intel-cprof' | egrep -i $PKGNUM | egrep -e 'mkl')"
    VPRINT "Cpro Fortran RPM check for mkl installs - RESULT1=<$RESULT1>"
    if [ -n "$RESULT1" ]; then
	# error - cannot remove fortran until dependent product components are removed first
	local THIS_RPM_ARCH=$(rpm -q --queryformat %{ARCH} $CHOSEN_RPM)
	local THIS_MKL_RPM_ARCH=""
	for THIS_MKL_RPM in $RESULT1
	do
            THIS_MKL_RPM_ARCH=$(rpm -q --queryformat %{ARCH} $THIS_MKL_RPM)
	    if [ "$THIS_MKL_RPM_ARCH" = "$THIS_RPM_ARCH" ]; then    
            echo "$UNS_STRING_3"
	        read CONTINUE
            RETURN_VAL=1
            return
        fi
        done             
    fi
    local RESULT1="$(rpm -qa | egrep -e 'intel-cproc' | egrep -i $PKGNUM | egrep -v -e 'mkl' -e 'idb' -e 'tbb' -e 'ipp')"
    if [ -n "$RESULT1" ]; then
        DO_PRESERVE_ICC RPM
        rpm "$USER_ARGUMENTS" "$CHOSEN_RPM"
        RETURN_VAL=$?
        DO_RESTORE_ICC RPM
    else
        rpm "$USER_ARGUMENTS" "$CHOSEN_RPM"
        RETURN_VAL=$?
    fi
}


# Remove chosen RPM.
DO_RPM_UNINSTALL ()
{
    VPRINT "DO_RPMUINSTALL()"
    INDEX=0
    DISPLAY_HEADER=0
    #echo "$@"  
    for INSTALLED_RPM in $@ ; do
     	DISPLAY_HEADER=1
    done
    
    if [ $DISPLAY_HEADER = "1" ] ; then
       VPRINT "$0: $LOCAL_VERSION"
       echo
       # which would you like to uninstall?
       echo "$UNS_STRING_4"
       DISPLAY_HEADER=0 
       # 0. uninstall all comp pro $PACKAGE_NUMBER components
       echo "$UNS_STRING_5 $PACKAGE_NUMBER" 
    fi

    for INSTALLED_RPM in $@ ; do
        INDEX="$(($INDEX+1))"
	echo -n "$INDEX.   "
	# old RPM-data based display procedure
	# rpm -qi "$INSTALLED_RPM" | grep Summary | cut -d: -f2-3
	# end old method
	#
	# new method as employed within non-RPM uninstall
        # PACKAGEID="$(echo $PROD | cut -d':' -f2)"
        # RPMNAME="$(echo $PROD | cut -d':' -f3)"
        # LOCATION="$(echo $PROD | cut -d':' -f4)"
        # LOG_FILE="$(echo $PROD | cut -d':' -f5)"
        # UPDATE_DISPLAY_VARIABLES
	RPMNAME=$INSTALLED_RPM
	PACKAGEID=$THIS_PACKAGEID
        PRODUCT=$(echo "$RPMNAME" | grep -o -E "(idb|tbb|ipp|mkl|cproc${PKGNUM}-|cproc${PKGNUM}e-|cprof${PKGNUM}-|cprof${PKGNUM}e-)")
	RPM_ARCH_TEST=$(rpm -q --queryformat %-{name}-%{version}-%{release}-%{arch}"\n" $RPMNAME)
	if [ -n "$RPM_ARCH_TEST" ]; then
	    I386_RESULT=$(echo $RPM_ARCH_TEST | grep i386)
	    IA64_RESULT=$(echo $RPM_ARCH_TEST | grep ia64)
	    X86_64_RESULT=$(echo $RPM_ARCH_TEST | grep x86_64)
	    if [ "$I386_RESULT" = "" ] && \
	       [ "$IA64_RESULT" = "" ] && \
	       [ "$X86_64_RESULT" = "" ]; then
	        VPRINT "Warning - Architecture test results suspect"
	        ARCH=i386
	    elif [ -n "$I386_RESULT" ]; then
	        ARCH=i386
	    elif [ -n "$IA64_RESULT" ]; then
	        ARCH=ia64
	    elif [ -n "$X86_64_RESULT" ]; then
	        ARCH=x86_64
	    fi
	else
	    ARCH=i386
	    VPRINT "Warning - Architecture test results suspect"
	fi
	VPRINT "RPM_UNINSTALL Call - ARCH=$ARCH"
	UPDATE_DISPLAY_VARIABLES
	echo $signon
	local RESULT1="$(echo $INSTALLED_RPM  | egrep -e 'intel-cproc' | egrep -v -e 'mkl' -e 'idb' -e 'tbb' -e 'ipp')"
	if [ -n "$RESULT1" ]; then
	    # add note that this is required for c/c++ library components
            echo "$UNS_STRING_6"
	else
	    local RESULT1="$(echo $INSTALLED_RPM  | egrep -e 'intel-cprof' | egrep -v -e 'mkl' -e 'idb')"
	    if [ -n "$RESULT1" ]; then
	        # add note that this is required for fortran library components
                echo "$UNS_STRING_7"
	    fi 
        fi
    done
    echo ""
    MAX_INDEX=$INDEX
    if [ $MAX_INDEX -ge 1 ] &> /dev/null ; then
	# x. Exit
        echo "$UNS_STRING_8"
	# Please make a selection
    	echo -n "$UNS_STRING_9"
	REPEAT_LOOP=1
        while [ "$REPEAT_LOOP" = "1" ]
	do
    		read CHOSEN_INDEX &> /dev/null
    	    if [ "$CHOSEN_INDEX" = x ] &>/dev/null ; then
		# Exiting ...
		echo "$UNS_STRING_10"
		exit 0
    	    elif [ $CHOSEN_INDEX -ge 1 ] &> /dev/null && [ $CHOSEN_INDEX -le $MAX_INDEX ] &> /dev/null ; then
		REPEAT_LOOP=0
		CHOSEN_RPM="$(echo $INSTALLED_RPM_LIST | cut -d' ' -f"$CHOSEN_INDEX")"
		CHOSEN_FULL_NAME="$(rpm -qi $CHOSEN_RPM | grep Summary | cut -d: -f2-3)"
		DEFAULT_ARGUMENTS='-e'
		echo
                
		# what RPM options do you want to use to uninstall
		echo "$UNS_STRING_11"
		echo -n "$CHOSEN_FULL_NAME [$DEFAULT_ARGUMENTS]?   :   "
		read USER_ARGUMENTS &> /dev/null
		if [ -z "$USER_ARGUMENTS" ] &> /dev/null ; then
	    	    USER_ARGUMENTS="$DEFAULT_ARGUMENTS"
		fi
		# uninstalling $CHOSEN_FULL_NAME
		echo "$UNS_STRING_12 $CHOSEN_FULL_NAME"
		
		local RESULT1="$(echo $CHOSEN_RPM  | egrep -e 'intel-cproc' | egrep -v -e 'mkl' -e 'idb' -e 'tbb' -e 'ipp')"
		VPRINT "RPM Uninstall sweep - CHOSEN_RPM=<$CHOSEN_RPM>"
		VPRINT "RPM uninstall - is this Cpro C++ compiler? RESULT1=<$RESULT1>"
		if [ -n "$RESULT1" ]; then 
		    VPRINT "RPM uninstall of cproc c/c++ compiler ..."
		    UNINSTALL_CPROC_RPM_AND_ITS_DEPENDENCIES
		else
		    local RESULT1="$(echo $CHOSEN_RPM  | egrep -e 'intel-cprof' | egrep -v -e 'mkl' -e 'idb')"
		    VPRINT "RPM uninstall - is this Cpro Fortran compiler? RESULT1=<$RESULT1>"
		    if [ -n "$RESULT1" ]; then 
			VPRINT "RPM uninstall of cproc fortran compiler ..."
			UNINSTALL_CPROF_RPM_AND_ITS_DEPENDENCIES
		    else
		        # is this TBB? if so, remove symlinks
		        local RESULT1="$(echo $CHOSEN_RPM  | egrep -e 'intel-cproc' | egrep -e 'tbb')"
			if [ -n "$RESULT1" ]; then
                             VPRINT "RPM removal of TBB symlinks in progress ..."
	                     #TBB_RPM=$(rpm -qa | grep -e 'intel-' | grep -e 'cpro[cf]' | grep tbb | grep ${PKGNUM})
                             local TBB_PURGE_DIR=$(rpm -ql "$CHOSEN_RPM" | grep example | head -1)
                             pushd $TBB_PURGE_DIR/.. 2> /dev/null > /dev/null
	                     VPRINT "Now in TBB_PURGE_DIR $TBB_PURGE_DIR --- pwd=`pwd`"
#                             echo 
	                     echo "$UNS_STRING_22"
	                     local FILEA=$(find . -type l -name 'bin' -print 2> /dev/null)
	                     local FILE_CHECK=$(ls -l $FILEA | grep kernel)
	                     if [ -n "$FILE_CHECK" ]; then
                                  rm -rf $FILEA 2> /dev/null
	                     else
	                         VPRINT "No TBB 'bin' link file found"
	                     fi
	                     local FILEB=$(find . -type l -name 'lib' -print 2> /dev/null)
	                     local FILE_CHECK=$(ls -l $FILEB | grep kernel)
	                     if [ -n "$FILE_CHECK" ]; then
                                 rm -rf $FILEB 2> /dev/null
	                     else
	                         VPRINT "No TBB 'lib' link file found"
	                     fi
                             popd 2> /dev/null > /dev/null
#                             echo
			fi
		        # is this IDB? if so, remove symlinks
		        local RESULT1="$(echo $CHOSEN_RPM  | egrep -e 'intel-cpro' | egrep -e 'idb')"
			if [ -n "$RESULT1" ]; then
                            VPRINT "RPM removal of IDB symlinks in progress ..."
	                    # B_RPM=$(rpm -qa | grep -e 'intel-' | grep -e 'cpro[cf]' | grep idb | grep ${PKGNUM})
                            local IDB_PURGE_DIR=$(rpm -ql "$CHOSEN_RPM" | grep 'idb/gui' | head -1)
			    VPRINT IDB_PURGE_DIR=$IDB_PURGE_DIR
                            pushd $IDB_PURGE_DIR/.. 2> /dev/null > /dev/null
	                    VPRINT "Now in IDB_PURGE_DIR ${IDB_PURGE_DIR}/.. --- pwd=`pwd`"
#                            echo 
	                    echo "$UNS_STRING_22"
                            local FILEA=$(find . -name 'com.intel.debugger.help_1.0.0' -type l -print 2> /dev/null)
	                    if [ -z "$FILEA" ]; then
	                        VPRINT "Cannot find file 'com.intel.debugger.help_1.0.0' link file"
	                    else
	                        VPRINT "File 'com.intel.debugger.help_1.0.0' link is $FILEA"
	                        rm -rf $FILEA 2> /dev/null 
	                    fi
                            VPRINT "RPM removal of IDB webhelp (fed9 only) in progress ..."
			    IS_OS_FEDORA_9
			    if [ "$OS_FEDORA_9" = 1 ]; then
                                VPRINT "For webhelp removal, now in IDB_PURGE_DIR ${IDB_PURGE_DIR}/.. --- pwd=`pwd`"
                                local FILEA=$(find . -name 'webhelp' -type d -print 2> /dev/null)
                                if [ -z "$FILEA" ]; then
                                    VPRINT "Cannot find file 'webhelp' directory"
                                else
				    if [ -s ${FILEA}/styles_l.css ]; then
                                        VPRINT "webhelp directory is $FILEA"
                                        rm -rf $FILEA 2> /dev/null 
			            fi
                                fi
                            fi
                            popd 2> /dev/null > /dev/null
			                    fi
			rpm "$USER_ARGUMENTS" "$CHOSEN_RPM"
			RETURN_VAL=$?
		    fi
		fi
		if [ "$RETURN_VAL" = 0 ]; then
		    # Uninstall successful
		    echo "$UNS_STRING_13"
		else
		    # Uninstall unsuccessful
		    echo "$UNS_STRING_14"
		fi
    	elif [ -n "$CHOSEN_INDEX" ] && [ $CHOSEN_INDEX = 0 ]; then
            UNINSTALL_ALL_CHOICE=1
            UNINSTALL_ALL_RPM 
            TINI_SCRIPT
    	else
	    REPEAT_LOOP=1
	    echo
	# inappropriate choice. try 0, x, or the number of a component
	    echo "$UNS_STRING_15"
	    # which would you like to uninstall?
    	    echo -n "$UNS_STRING_4"
    	fi
        done
     fi
}


# process rpm install list
RPM_BASED_UNINSTALL_CHOICES ()
{
    VPRINT "RPM_BASED_UNINSTALL_CHOICES()"
    echo
    while INSTALLED_RPM_LIST="$(rpm -qa | grep -e 'intel-' | grep -e 'cpro[cf]' | grep -e ${PKGNUM} | sort)" && [ -n "$INSTALLED_RPM_LIST" ] ; do
      	echo
    	DO_RPM_UNINSTALL $INSTALLED_RPM_LIST
    done
   
    ## This special call is required if all compiler components have 
    ## been uninstalled but EP has not been uninstalled yet.
    DO_RPM_UNINSTALL
    echo
    # no Cpro $PACKAGE_NUMBER compilers or components found
    echo "$UNS_STRING_16 $PACKAGE_NUMBER"
    echo
    if [ -f "$INTEL_SDP_PRODUCTS_DB" ]; then
	VAR="$(cat $INTEL_SDP_PRODUCTS_DB | egrep '<:')"
	if [ -n "$VAR" ]; then
    		echo
		# some may have been installed as non-root or without RPM
		# use uninstaller for that product version
                echo "$UNS_STRING_17"
    		echo
	fi
    fi
    	
}


# Main routine for flat file based uninstallation.
NON_RPM_BASED_UNINSTALLATION ()
{
    VPRINT "NON_RPM_BASED_UNINSTALLATION()"
	#clear
        if [ -f "$INTEL_SDP_PRODUCTS_DB" ]; then
		while VAR="$(cat $INTEL_SDP_PRODUCTS_DB | egrep '<:')" && [ -n "$VAR" ]; 
		do
    			DISPLAY_NON_RPM_MENU
		done
        	DISPLAY_NON_RPM_MENU
	else
		if [ "$ROOT_USER" = 0 ] ; then
		        echo 
			# no products found to e installed.  
			# if installed as root, you must become root to uninstall them
			echo "$UNS_STRING_18"
			# echo "$PACKAGE_NUMBER"
			echo
		fi
		exit
	fi
}

# remove shell directories left behind
REMOVE_EMPTY_DIRS ()
{
    VPRINT "REMOVE_EMPTY_DIRS()"
    local rootnodes="$@"
    local childnodes=''
    if [ -n "$rootnodes" ] ; then
        # find empty directories
        childnodes=$(find $rootnodes -empty -type d 2>&1)
        # if find returns an error
        if (($?)) ; then
            # display error messages
            echo -e "$childnodes" | \
                grep 'find:' | sed s@'^'@'REMOVE_EMPTY_DIRS: '@g
            # strip error messages from list of empty directories
            childnodes=$(echo "$childnodes" | grep -v 'find:')
        fi
        if [ -n "$childnodes" ] ; then
            # remove empty directories
            rmdir -p $childnodes > /dev/null 2>&1
        fi
    fi
}

# create a version of arg1 file in arg2 that contains lins that are NOT directories
DIR_STRIP ()
{
    VPRINT "DIR_STRIP()"
    local INFILE=$1
    local OUTFILE=$2
    local DATA_LINE=""
    if [ ! -s $INFILE ]; then
	# no arg1 found
        echo "$UNS_STRING_19"
	TINI_SCRIPT
    fi 
    touch $OUTFILE
    if [ ! -e $OUTFILE ]; then
	# cannot create temporary file
        echo "$UNS_STRING_20"
	echo "$OUTFILE"
	TINI_SCRIPT
    fi
    # exec < $INFILE
    while read DATA_LINE
    do
        if [ ! -d $DATA_LINE ]; then
	    echo "$DATA_LINE" >> $OUTFILE
        else
	    VPRINT "DIR_STRIP() - Discarding entry <$DATA_LINE>"
        fi
    done < $INFILE
}

# remove a specific component via non-rpm means
UNINSTALL_NON_RPM () 
{
    VPRINT "UNINSTALL_NONRPM()"
    local PROD="$1"
    local PACKAGEID="$(echo $PROD | cut -d':' -f2)"
    local RPMNAME="$(echo $PROD | cut -d':' -f3)"
    local LOCATION="$(echo $PROD | cut -d':' -f4)"
    local FILE="$(echo $PROD | cut -d':' -f5)"
   
    # check if this is a TBB install ... if so, need to clean non-RPM symlinks
    RESULT1=$(echo $RPMNAME | grep 'tbb')
    if [ -n "$RESULT1" ]; then
        local THIS_IS_TBB=1
    else
        local THIS_IS_TBB=0
    fi

    # check if this is a IDB install ... if so, need to clean non-RPM symlinks and possiblyy webhelp
    RESULT1=$(echo $RPMNAME | grep 'idb')
    if [ -n "$RESULT1" ]; then
        local THIS_IS_IDB=1

        VPRINT "RPM removal of IDB symlinks in progress ..."
        local IDB_PURGE_DIR="$LOCATION/idb"
        pushd $IDB_PURGE_DIR 2> /dev/null > /dev/null
	echo 
        VPRINT "Now in IDB_PURGE_DIR ${IDB_PURGE_DIR} --- pwd=`pwd`"
        echo 
        echo "$UNS_STRING_22"
        local FILEA=$(find . -name 'com.intel.debugger.help_1.0.0' -type l -print 2> /dev/null)
        if [ -z "$FILEA" ]; then
        VPRINT "Cannot find file 'com.intel.debugger.help_1.0.0' link file"
        else
	    VPRINT "File 'com.intel.debugger.help_1.0.0' link is $FILEA"
            rm -rf $FILEA 2> /dev/null 
        fi
        VPRINT "RPM removal of IDB webhelp (fed9 only) in progress ..."
	IS_OS_FEDORA_9
	if [ "$OS_FEDORA_9" = 1 ]; then
            local FILEA=$(find . -name 'webhelp' -type d -print 2> /dev/null)
            if [ -z "$FILEA" ]; then
            VPRINT "Cannot file 'webhelp' directory"
            else
	        if [ -s ${FILEA}/styles_l.css ]; then
                   rm -rf $FILEA 2> /dev/null 
	        fi
            fi
        fi
        popd 2> /dev/null > /dev/null
    else
        local THIS_IS_IDB=0
    fi
    if [ "$DEFAULT_MODE" != 1 ]; then
	# uninstalling $RPMNAME
	echo "$UNS_STRING_21 $RPMNAME"
	# removing files
	echo "$UNS_STRING_22"
    fi
   
    if [ ! -f "$FILE" ]; then
	echo 
	echo
	# $0: UNINSTALL_NON_RPM - ERROR - Uninstallation cannot continue for this component
	echo "$UNS_STRING_23"
	# echo Missing $FILE
	echo "$UNS_STRING_24 $FILE"
	return
    fi
    while read VAR;  do
        if [ ! -d "$VAR" ]; then
            rm -f "$VAR"
        fi
    done < $FILE
    rm -f $FILE
    
    if [ "$THIS_IS_TBB" = 1 ]; then
	echo 
	# Removing TBB non-RPM symlinks ...
	echo "$UNS_STRING_25"
        #find $LOCATION/tbb -type l -exec rm -rf {} \; 2> /dev/null
	echo
        THIS_IS_TBB=0
        VPRINT "RPM removal of TBB symlinks in progress ..."
	#TBB_RPM=$(rpm -qa | grep -e 'intel-' | grep -e 'cpro[cf]' | grep tbb | grep ${PKGNUM})
        #local TBB_PURGE_DIR=$(rpm -ql "$CHOSEN_RPM" | grep example | head -1)
        pushd $LOCATION/tbb 2> /dev/null > /dev/null
	VPRINT "Now in TBB_PURGE_DIR $LOCATION/tbb --- pwd=`pwd`"
        echo 
	echo "$UNS_STRING_22"
	local FILEA=$(find . -type l -name 'bin' -print 2> /dev/null)
	local FILE_CHECK=$(ls -l $FILEA | grep kernel)
	if [ -n "$FILE_CHECK" ]; then
            rm -rf $FILEA 2> /dev/null
	else
	    VPRINT "No TBB 'bin' link file found"
	fi
	local FILEB=$(find . -type l -name 'lib' -print 2> /dev/null)
	local FILE_CHECK=$(ls -l $FILEB | grep kernel)
	if [ -n "$FILE_CHECK" ]; then
            rm -rf $FILEB 2> /dev/null
	else
	    VPRINT "No TBB 'lib' link file found"
	fi
        popd 2> /dev/null > /dev/null
        echo
    fi

    if [ "$THIS_IS_IDB" = 1 ]; then
	# Removing IDB non-RPM symlinks ...
	echo "$UNS_STRING_26"
        find $LOCATION/idb -type l -exec rm -rf {} \; 2> /dev/null
	echo
        THIS_IS_IDB=0
    fi

    if [ "$DEFAULT_MODE" != 1 ]; then
        # Removing only EMPTY directories ...
	echo "$UNS_STRING_27"
    fi
    REMOVE_EMPTY_DIRS "$LOCATION"

    M_PROD=$(echo $PROD | sed s@'/'@'\\/'@g)            
        sed "/$M_PROD/D" $INTEL_SDP_PRODUCTS_DB > $INTEL_SDP_PRODUCTS_DB.new

    mv "$INTEL_SDP_PRODUCTS_DB" "$INTEL_SDP_PRODUCTS_DB.old"
    mv "$INTEL_SDP_PRODUCTS_DB.new" "$INTEL_SDP_PRODUCTS_DB"
    #echo
}


# manage non-rpm uninstall menu
DISPLAY_NON_RPM_MENU () 
{
    VPRINT "DISPLAY_NON_RPM_MENU()"
    IFORT_INSTALLED=0
    IFORT_IDB_INSTALLED=0
    IFORT_MKL_INSTALLED=0
    ICC_INSTALLED=0
    ICC_IDB_INSTALLED=0
    ICC_MKL_INSTALLED=0
    ICC_TBB_INSTALLED=0
    ICC_IPP_INSTALLED=0
    PRESERVE_FORTRAN=0
    PRESERVE_ICC=0
    INSTALLED_PRODS=""
    INSTALLED_PRODS="$(cat $INTEL_SDP_PRODUCTS_DB | egrep '<:' | grep $PKGNUM)"
    INDEX=0
    DISPLAY_HEADER=0 
       
    if [ "$INSTALLED_PRODS" = "" ]; then
        if [ "$DEFAULT_MODE" != 1 ]; then
	    echo
	    if [ "$ROOT_USER" = 0 ] ; then
	        echo "$UNS_STRING_18"
	        echo
	    else
	        echo "$UNS_STRING_16"
	        echo
	    fi
	fi
        exit
    fi
 
        if [ -n "$INSTALLED_PRODS" ]; then
		DISPLAY_HEADER=1
        fi

    	if [ "$DISPLAY_HEADER" = 1 ] ; then
		VPRINT "$0: $LOCAL_VERSION"
       		echo
       		# Which of the following would you like to uninstall?
		echo "$UNS_STRING_4"
		echo 
       		DISPLAY_HEADER=0 
    	fi
	echo
	if [ -n "$INSTALLED_PRODS" ]; then
	    # let "INDEX += 1"
	    # 0.    Uninstall All Intel(R) Compiler Professional $PACKAGE_NUMBER Components
	    echo "$UNS_STRING_5 $PACKAGE_NUMBER"
	    UNINSTALL_ALL_CHOICE=1 	
	fi
    	for PROD in $INSTALLED_PRODS; do
        	PACKAGEID="$(echo $PROD | cut -d':' -f2)"
        	RPMNAME="$(echo $PROD | cut -d':' -f3)"
        	LOCATION="$(echo $PROD | cut -d':' -f4)"
        	LOG_FILE="$(echo $PROD | cut -d':' -f5)"
		RESULT1="$(echo $RPMNAME | grep cproc | grep -v ipp | grep -v idb | grep -v tbb | grep -v mkl)"
		if [ -n "$RESULT1" ]; then
		    ICC_INSTALLED=1
                fi
		RESULT2="$(echo $RPMNAME | grep cprof | grep -v idb | grep -v mkl)"
		if [ -n "$RESULT2" ]; then
		    IFORT_INSTALLED=1
                fi
        	UPDATE_DISPLAY_VARIABLES 
       	 	let "INDEX += 1"
        	echo "$INDEX.    $DISPLAY_NAME" 
		if [ -n "$RESULT1" ]; then
		    #         (Required for C/C++ Compiler Profession MKL, TBB, IPP)
		    echo "$UNS_STRING_6"
		fi
		if [ -n "$RESULT2" ]; then
		    #         (Required for Fortran Compiler Profession MKL)
		    echo "$UNS_STRING_7"
		fi
		echo "                ( $LOCATION )"
    	done
    	MAX_INDEX=$INDEX 
        if [ "$MAX_INDEX" = 0 ]; then
		TINI_SCRIPT
        fi
	echo
	# x.    Exit
	echo "$UNS_STRING_8"
    	echo
    	# Please type a selection:    
    	echo -n "$UNS_STRING_9"
    	REPEAT_LOOP=1
    	while [ "$REPEAT_LOOP" = "1" ]; do
    		read CHOICE
        	REPEAT_LOOP=0
    		if [ "$CHOICE" = "x" ]; then
        		echo
        		# Exiting uninstallation ...
        		echo "$UNS_STRING_10"
        		exit
    		fi
    		if [ -n "$CHOICE" ] && [ $CHOICE = 0 ]; then
                    UNINSTALL_ALL_CHOICE=1
                    UNINSTALL_ALL_NON_RPM 
                    TINI_SCRIPT
		fi
    		if [ -n $CHOICE ] && [ $CHOICE -gt 0 ] &> /dev/null && [ $CHOICE -lt $(($INDEX+1)) ]; then
        		echo
    		else
			REPEAT_LOOP=1
        		echo
			# inappropriate choice. try 0, x, or the number of a component
			echo "$UNS_STRING_15"
    			# Please type a selection:    
			echo -n "$UNS_STRING_9"
    		fi
	done

         
    INDEX=0
    for PROD in $INSTALLED_PRODS; do
        let "INDEX += 1"
	if [ "$INDEX" = "$CHOICE" ]; then
            # check if this is a collision uninstall 
            PACKAGEID="$(echo $PROD | cut -d':' -f2)"
            RPMNAME="$(echo $PROD | cut -d':' -f3)"
            RPM_ARCH="$(echo $RPMNAME | cut -d'.' -f3)"
            LOCATION="$(echo $PROD | cut -d':' -f4)"
            LOG_FILE="$(echo $PROD | cut -d':' -f5)"
            RESULT1="$(echo $RPMNAME | grep cproc | grep -v ipp | grep -v idb | grep -v tbb | grep -v mkl)"
	    # if this is cproc, set up for protection of equivalent cprof
	    if [ -n "$RESULT1" ] && [ $IFORT_INSTALLED = 1 ]; then
		PRESERVE_FORTRAN=1
            fi
	    if [ -n "$RESULT1" ]; then
	        # if this is cproc, set up for enforcement of compiler to be installed for
		#  mkl, ipp, or tbb 
	        if [ "$ICC_MKL_INSTALLED" = 1 ] || [ "$ICC_IPP_INSTALLED" = 1 ] || \
		    [ "$ICC_TBB_INSTALLED" = 1 ]; then
		    local ARCH_TEST=$(echo "$INSTALLED_PRODS" | grep -e 'ipp' -e 'tbb' -e 'mkl' | grep "$RPM_ARCH")
		    if [ -n "$ARCH_TEST" ]; then
		        # Cannot remove C/C++ Compiler until C/C++ compiler dependent product
		        # components IPP, TBB, and/or MKL are uninstalled.
		        # Press ENTER to continue
		        echo $UNS_STRING_2
		        read CONTINUE
		        break
		    fi
                fi
            fi
	    # if this is cprof, set up for protection of equivalent cproc
	    RESULT3="$(echo $RPMNAME | grep cprof | grep -v idb | grep -v mkl)"
	    if [ -n "$RESULT3" ] && [ $ICC_INSTALLED = 1 ]; then
	        PRESERVE_ICC=1
	    fi
	    if [ -n "$RESULT3" ]; then
	        # if this is cprof, set up for enforcement of MKL requirement
		if [ "$IFORT_MKL_INSTALLED" = 1 ]; then
                    echo
		    local ARCH_TEST=$(echo "$INSTALLED_PRODS" | grep cprof | grep mkl | grep "$RPM_ARCH")
		    if [ -n "$ARCH_TEST" ]; then
		        # Cannot remove Fortran Compiler until Fortran compiler dependent
		        # MKL product component is uninstalled.
		        # Press ENTER to continue"
		        echo "$UNS_STRING_3"
		        read CONTINUE
		        break
		    fi
                fi
            fi

	    # need to add check for removal of over-written MKLs and IDBs

	    if [ $PRESERVE_ICC = 1 ]; then
	        DO_PRESERVE_ICC
	    fi
	    if [ $PRESERVE_FORTRAN = 1 ]; then
	        DO_PRESERVE_FORTRAN
	    fi
	    
            UNINSTALL_NON_RPM "$PROD"

	    if [ $PRESERVE_ICC = 1 ]; then
	        DO_RESTORE_ICC
	    fi
	    if [ $PRESERVE_FORTRAN = 1 ]; then
	        DO_RESTORE_FORTRAN
	    fi

        fi
     done
}

# preserve a compiler pro c/c++ product
#  - protects from uninstall of shared files by companion fortran install
DO_PRESERVE_ICC () 
{
    VPRINT "DO_PRESERVE_ICC()"
    if [ "$1" = "RPM" ]; then
        echo
        # Preserving existing C/C++ compiler RPM installation ...
        echo "$UNS_STRING_28"
	local RPM_PRESERVE=1
    else
        echo
        # Preserving existing C/C++ compiler installation ...
        echo "$UNS_STRING_28"
        echo
	local RPM_PRESERVE=0
    fi
    TMP_ICC_LIST=$LOCATION/../.tmp_icc_list.$$.txt
    if [ "$RPM_PRESERVE" = 0 ]; then
        local RESULT2="$(cat $INTEL_SDP_PRODUCTS_DB | egrep '<:' | grep $PKGNUM | grep cproc | grep -v ipp | grep -v idb | grep -v tbb | grep -v mkl)"
        VPRINT "DO_PRESERVE_ICC() - RESULT2 (check for ICC details) = $RESULT2"
        if [ ! -n "$RESULT2" ]; then
            # $0: DO_PRESERVE_ICC - Fatal error getting install location
	    echo "$UNS_STRING_30"
        fi
        local PACKAGEID="$(echo $RESULT2 | cut -d':' -f2)"
        local RPMNAME="$(echo $RESULT2 | cut -d':' -f3)"
        local LOCATION="$(echo $RESULT2 | cut -d':' -f4)"
        local LOG_FILE="$(echo $RESULT2 | cut -d':' -f5)"
    else
        local RPMNAME="$(rpm -qa | egrep -e 'intel-cproc' | egrep -i $PKGNUM | egrep -v -e 'mkl' -e 'idb' -e 'ipp' -e 'tbb')"
	local LOG_FILE=$TMP/.tmp_icc_rpm_list.txt
	rpm -ql $RPMNAME > $LOG_FILE
	VPRINT "PRESERVE_ICC RPM list results in $LOG_FILE"
	VPRINT "line count for RPM file is `wc -l $LOG_FILE`"
    fi
    VPRINT "RPMNAME for PRESERVE is $RPMNAME"
    if [ "$VERBOSE_MODE" = 1 ]; then
        DIR_STRIP $LOG_FILE $TMP_ICC_LIST
    else
        DIR_STRIP $LOG_FILE $TMP_ICC_LIST 2> /dev/null > /dev/null
    fi
    VPRINT "TMP_ICC_LIST $TMP_ICC_LIST created."
    TMP_ICC_FILE=$LOCATION/../.tmp_icc.$$.tgz
    if [ "$VERBOSE_MODE" = 1 ]; then
        echo "Executing this command: tar czpfT $TMP_ICC_FILE $TMP_ICC_LIST"
        tar czpfT $TMP_ICC_FILE $TMP_ICC_LIST
    else
        tar czpfT $TMP_ICC_FILE $TMP_ICC_LIST 2> /dev/null > /dev/null
    fi
    local RESULT=$?
    if [ "$RESULT" != 0 ]; then
	VPRINT "Tar execution error creating content of C/C++ preservation file"
    fi
    echo 
    VPRINT "rm -rf $TMP_ICC_LIST"
    rm -rf $TMP_ICC_LIST
}

# preserve a compiler pro fortran product
#  - protects from uninstall of shared files by companion c/c++ install
DO_PRESERVE_FORTRAN () 
{
    VPRINT "DO_PRESERVE_FORTRAN()"
    if [ "$1" = "RPM" ]; then
        echo
        # Preserving existing Fortran compiler RPM installation ...
	echo "$UNS_STRING_31"
        echo
	local RPM_PRESERVE=1
    else
        echo
        # Preserving existing Fortran compiler installation ...
	echo "$UNS_STRING_32"
        echo
	local RPM_PRESERVE=0
    fi
    TMP_FORTRAN_LIST=$LOCATION/../.tmp_fortran_list.$$.txt
    if [ "$RPM_PRESERVE" = 0 ]; then
        local RESULT2="$(cat $INTEL_SDP_PRODUCTS_DB | egrep '<:' | grep $PKGNUM | grep cprof | grep -v idb | grep -v mkl)"
        if [ ! -n "$RESULT2" ]; then
            # $0: DO_PRESERVE_FORTAN - Fatal error getting install location
	    echo "$UNS_STRING_33"
        fi
        local PACKAGEID="$(echo $RESULT2 | cut -d':' -f2)"
        local RPMNAME="$(echo $RESULT2 | cut -d':' -f3)"
        local LOCATION="$(echo $RESULT2 | cut -d':' -f4)"
        local LOG_FILE="$(echo $RESULT2 | cut -d':' -f5)"
    else
        local RPMNAME="$(rpm -qa | egrep -e 'intel-cprof' | egrep -i $PKGNUM | egrep -v -e 'mkl' -e 'idb')"
	local LOG_FILE=$TMP/.tmp_fortran_rpm_list.txt
	rpm -ql $RPMNAME > $LOG_FILE
	VPRINT "PRESERVE_FORTRAM RPM list results in $LOG_FILE"
	VPRINT "line count for RPM file is `wc -l $LOG_FILE`"
    fi
    VPRINT "RPMNAME for PRESERVE is $RPMNAME"
    if [ "$VERBOSE_MODE" = 1 ]; then
        DIR_STRIP $LOG_FILE $TMP_FORTRAN_LIST
    else
        DIR_STRIP $LOG_FILE $TMP_FORTRAN_LIST 2> /dev/null > /dev/null
    fi
    VPRINT "TMP_FORTRAN_LIST $TMP_FORTRAN_LIST created."
    TMP_FORTRAN_FILE=$LOCATION/../.tmp_fortran.$$.tgz
    if [ "$VERBOSE_MODE" = 1 ]; then
	echo "Executing this command: tar czpfT $TMP_FORTRAN_FILE $TMP_FORTRAN_LIST"
        tar czpfT $TMP_FORTRAN_FILE $TMP_FORTRAN_LIST 
    else
        tar czpfT $TMP_FORTRAN_FILE $TMP_FORTRAN_LIST 2> /dev/null > /dev/null
    fi
    local RESULT=$?
    if [ "$RESULT" != 0 ]; then
	VPRINT "Tar execution error creating content of Fortran preservation file"
    fi
    echo 
    # echo "File $TMP_FORTRAN_FILE created ... press RETURN to continue."
    # read CONTINUE
    # read CONTINUE
    # sleep 5
    VPRINT "rm -rf $TMP_FORTRAN_LIST"
    rm -rf $TMP_FORTRAN_LIST
}

## restore c/c++ compiler after removing companion fortran compiler has been uninstalled
DO_RESTORE_ICC () 
{
    VPRINT "DO_RESTORE_ICC()"
    if [ "$1" = "RPM" ]; then
        echo
        # Restoring existing C/C++ compiler RPM installation ...
        echo "$UNS_STRING_34"
	return
    else
        echo
        # Restoring existing C/C++ compiler installation ...
        echo "$UNS_STRING_35"
        echo
    fi
    pushd / 2> /dev/null > /dev/null
    if [ -s $TMP_ICC_FILE ]; then
        VPRINT "Restoring contents from file $TMP_ICC_FILE"
	if [ "$VERBOSE_MODE" = 1 ]; then
	    echo "Executing this command: tar xzpf $TMP_ICC_FILE"
            tar xzpf $TMP_ICC_FILE
        else
            tar xzpf $TMP_ICC_FILE 2> /dev/null > /dev/null
	fi
        RESULT=$?
	if [ "$RESULT" != 0 ]; then
	        # Error extracting content from C/C++ preservation file
		echo "$UNS_STRING_36"
        fi
    else
        # ERROR: Cannot find C/C++ restore file $TMP_ICC_FILE
        echo "$UNS_STRING_37 $TMP_ICC_FILE"
    fi
    rm -rf $TMP_ICC_FILE
    popd 2> /dev/null > /dev/null
    # Restoration completed.
    echo "$UNS_STRING_38"
    sleep 2
}

## restore fortran compiler after removing companion c/c++ compiler has been uninstalled
DO_RESTORE_FORTRAN () 
{
    VPRINT "DO_RESTORE_FORTRAN()"
    if [ "$1" = "RPM" ]; then
        echo
        # Restoring existing Fortran compiler RPM installation ...
        echo "$UNS_STRING_39"
	echo
	return
    else
        echo
        # Restoring existing Fortran compiler installation ...
        echo "$UNS_STRING_40"
    fi
    pushd / 2> /dev/null > /dev/null
    if [ -s $TMP_FORTRAN_FILE ]; then
        VPRINT "Restoring contents from file $TMP_FORTRAN_FILE"
	if [ "$VERBOSE_MODE" = 1 ]; then
            echo "Executing this command: tar xzpf $TMP_FORTRAN_FILE"
	    tar xzpf $TMP_FORTRAN_FILE
	else
	    tar xzpf $TMP_FORTRAN_FILE 2> /dev/null > /dev/null
	fi
        RESULT=$?
	if [ "$RESULT" != 0 ]; then
	        # Error extracting content from Fortran preservation file
		echo "$UNS_STRING_41"
        fi
    else
        # $0: ERROR - Cannot find Fortran restore file $TMP_FORTRAN_FILE
	echo "$UNS_STRING_42 $TMP_FORTRAN_FILE"
	TINI_SCRIPT
    fi
    rm -rf $TMP_FORTRAN_FILE
    popd 2> /dev/null > /dev/null
    # Restoration completed.
    echo "$UNS_STRING_38"
    sleep 2
}

# if verbose mode is enabled print the arg text
VPRINT () 
{
    if [ "$VERBOSE_MODE" = 1 ]; then echo $* ; fi
}

# remove all rpm files for PKGNUM
UNINSTALL_ALL_RPM ()
{
    VPRINT "UNINSTALL_ALL_RPM()"
    local UNINSTALL_ALL_RPM_LOG=/tmp/.$$.uninstall.log

    VPRINT "UNINSTALL_ALL_RPM()"
    # Get install dir from packages
    # build symlink removal list
    ERASE_LIST=$(rpm -qa | grep -e 'intel-' | grep -e 'cpro[cf]' | grep ${PKGNUM})
    VPRINT "ERASE_LIST=<$ERASE_LIST>"

    VPRINT "Checking for TBB removals ..."
    local RESULT1="$(echo $ERASE_LIST  | egrep -e 'intel-cproc' | egrep -e 'tbb')"
    if [ -n "$RESULT1" ]; then
        VPRINT "RPM removal of TBB symlinks in progress ..."
	TBB_RPM=$(rpm -qa | grep -e 'intel-' | grep -e 'cpro[cf]' | grep tbb | grep ${PKGNUM})
local THIS_ONE_RPM
for THIS_ONE_RPM in $TBB_RPM; do
        local TBB_PURGE_DIR=$(rpm -ql "$THIS_ONE_RPM" | grep example | head -1)
        pushd $TBB_PURGE_DIR/.. 2> /dev/null > /dev/null
	VPRINT "Now in TBB_PURGE_DIR $TBB_PURGE_DIR --- pwd=`pwd`"
#        echo 
	echo "$UNS_STRING_22"
	local FILEA=$(find . -type l -name 'bin' -print 2> /dev/null)
	local FILE_CHECK=$(ls -l $FILEA | grep kernel)
	if [ -n "$FILE_CHECK" ]; then
            rm -rf $FILEA 2> /dev/null
	else
	    VPRINT "No TBB 'bin' link file found"
	fi
	local FILEB=$(find . -type l -name 'lib' -print 2> /dev/null)
	local FILE_CHECK=$(ls -l $FILEB | grep kernel)
	if [ -n "$FILE_CHECK" ]; then
            rm -rf $FILEB 2> /dev/null
	else
	    VPRINT "No TBB 'lib' link file found"
	fi
        popd 2> /dev/null > /dev/null
#        echo
done
    fi

    VPRINT "Checking for IDB removals ..."
    local RESULT1="$(echo $ERASE_LIST  | egrep -e 'intel-cpro' | egrep -e 'idb')"
    if [ -n "$RESULT1" ]; then
        VPRINT "RPM removal of IDB symlinks in progress ..."
	IDB_RPM=$(rpm -qa | grep -e 'intel-' | grep -e 'cpro[cf]' | grep idb | grep ${PKGNUM})
local one
for THIS_ONE_RPM in $IDB_RPM; do
        local IDB_PURGE_DIR=$(rpm -ql "$THIS_ONE_RPM" | grep 'idb/gui' | head -1)
        pushd $IDB_PURGE_DIR 2> /dev/null > /dev/null
	VPRINT "Now in IDB_PURGE_DIR ${IDB_PURGE_DIR}/.. --- pwd=`pwd`"
#        echo 
	echo "$UNS_STRING_22"
        local FILEA=$(find . -name 'com.intel.debugger.help_1.0.0' -type l -print 2> /dev/null)
	if [ -z "$FILEA" ]; then
	    VPRINT "Cannot find file 'com.intel.debugger.help_1.0.0' link file"
	else
	    VPRINT "File 'com.intel.debugger.help_1.0.0' link is $FILEA"
 	    rm -rf $FILEA 2> /dev/null 
	fi
        VPRINT "RPM removal of IDB webhelp (fed9 only) in progress ..."
	IS_OS_FEDORA_9
	if [ "$OS_FEDORA_9" = 1 ]; then
            VPRINT "Now in IDB_PURGE_DIR ${IDB_PURGE_DIR}/.. --- pwd=`pwd`"
            local FILEA=$(find . -name 'webhelp' -type d -print 2> /dev/null)
            if [ -z "$FILEA" ]; then
            VPRINT "Cannot file 'webhelp' directory"
            else
	        if [ -s ${FILEA}/styles_l.css ]; then
                   rm -rf $FILEA 2> /dev/null 
	        fi
            fi
        fi
        popd 2> /dev/null > /dev/null
done
    fi

    VPRINT "Checking for *support removals ..."
    local RESULT1="$(echo $ERASE_LIST  | egrep -e 'intel-cpro' | egrep -e 'idb')"
    if [ -n "$RESULT1" ]; then
        VPRINT "RPM removal of support symlinks in progress ..."
	CORE_RPM=$(rpm -qa | grep -e 'intel-' | grep -e 'cpro[cf]'| grep ${PKGNUM} | head -1)
local THIS_ONE_RPM
for THIS_ONE_RPM in $CORE_RPM; do
#        local CORE_PURGE_DIR=$(rpm -ql "$CORE_RPM" | grep 'Documentation' | head -1)
        local CORE_PURGE_DIR=$(rpm -ql "$THIS_ONE_RPM" | grep 'Documentation' | head -1)
        pushd $CORE_PURGE_DIR/.. 2> /dev/null > /dev/null
	VPRINT "Now in CORE_PURGE_DIR $CORE_PURGE_DIR --- pwd=`pwd`"
#        echo 
	echo "$UNS_STRING_22"
        find . -name '*support' -type l -print -exec rm -rf {} \; 2> /dev/null
 #       find . -name '*support' -type l -print
        popd 2> /dev/null > /dev/null
done
    fi

    if [ -n "$ERASE_LIST" ]; then
        if [ "$VERBOSE_MODE" = 1 ]; then
	    for ERASE_RPM in $ERASE_LIST
	    do
		echo -n "Confirm erase: remove this RPM? ($ERASE_RPM) [yes/no] : "
		read CONFIRM_ERASE
		if [ "$CONFIRM_ERASE" = "yes" ]; then
		    echo
		    echo "$UNS_STRING_21"
		    echo "*** $ERASE_RPM ***"
	            rpm -e --nodeps $ERASE_RPM 2> $UNINSTALL_ALL_RPM_LOG
	        else
		    echo "Skipping erase of $ERASE_RPM per user preference"
                    echo
	        fi
	    done
        else
	    for ERASE_RPM in $ERASE_LIST
	    do
		echo
		echo "$UNS_STRING_21"
		echo "*** $ERASE_RPM ***"
	        rpm -e --nodeps $ERASE_RPM > /dev/null 2> $UNINSTALL_ALL_RPM_LOG
	    done
        fi
        RESULT=$?
    else
        VPRINT "$0: ERROR - No RPMs found in UNINSTALL_ALL_RPM"
        TINI_SCRIPT    
    fi

    if [ "$RESULT" != 0 ]; then
        echo "$0: ERROR in UNINSTALL_ALL_RPM" >&2
        cat $UNINSTALL_ALL_RPM_LOG >&2
        exit 1
    else
        exit 0
    fi
    
}

# removal an non-rpm installs
UNINSTALL_ALL_NON_RPM ()
{
    VPRINT "UNINSTALL_ALL_NON_RPM()"
    INDEX=1
    INSTALLED_PRODS=""
    INSTALLED_PRODS="$(cat $INTEL_SDP_PRODUCTS_DB | egrep '<:' | grep $PKGNUM)"
    VPRINT "PKGNUM=$PKGNUM"
    VPRINT "INSTALLED_PRODS=$INSTALLED_PRODS"
    for PROD in $INSTALLED_PRODS; do
        PACKAGEID="$(echo $PROD | cut -d':' -f2)"
        RPMNAME="$(echo $PROD | cut -d':' -f3)"
        LOCATION="$(echo $PROD | cut -d':' -f4)"
        LOG_FILE="$(echo $PROD | cut -d':' -f5)"
        UPDATE_DISPLAY_VARIABLES
        let "INDEX += 1"
    done
    let "INDEX -= 1"
                                                                                                                             
    for PROD in $INSTALLED_PRODS; do
        VPRINT "------------------------------------------------------------------------------"
        VPRINT "uninstalling $PROD from list $INSTALLED_PRODS"
        VPRINT "------------------------------------------------------------------------------"
        UNINSTALL_NON_RPM $PROD
    done
}


# set product labels to match component contents
UPDATE_DISPLAY_VARIABLES ()
{
# RPM names will look something like this
# intel-cproc110017-11.0-1.i386.rpm
# intel-cproc110017-11.0-1.ia64.rpm
# intel-cproc110017e-11.0-1.x86_64.rpm
# intel-cproc110017eidb-11.0-1.ia64.rpm
# intel-cproc110017iidb-11.0-1.i386.rpm
# intel-cproc110017iidbe-11.0-1.x86_64.rpm
# intel-cproc110017ipp32-11.0-1.i386.rpm
# intel-cproc110017ipp32e-11.0-1.x86_64.rpm
# intel-cproc110017ipp64-11.0-1.ia64.rpm
# intel-cproc110017mkl32-11.0-1.i386.rpm
# intel-cproc110017mkl32e-11.0-1.x86_64.rpm
# intel-cproc110017mkl64-11.0-1.ia64.rpm
# intel-cproc110017tbb32-11.0-1.i386.rpm
# intel-cproc110017tbb32e-11.0-1.x86_64.rpm
# intel-cproc110017tbb64-11.0-1.ia64.rpm

   VPRINT "UPDATE_DISPLAY_VARIABLES()"
   PRODUCT=$(echo "$RPMNAME" | grep -o -E "(idb|tbb|ipp|mkl|cproc${PKGNUM}-|cproc${PKGNUM}e-|cprof${PKGNUM}-|cprof${PKGNUM}e-)")
   VPRINT "UPDATE_DISPLAY_VARIABLES()-PRODUCT=$PRODUCT"
   VERSION=$(echo "$RPMNAME" | cut -d'-' -f3)
   VPRINT "UPDATE_DISPLAY_VARIABLES()-VERSION=$VERSION"
   TEMP_ARCH=$ARCH
   ARCH=$(echo "$RPMNAME" | grep -o -E '(i386|ia64|x86_64)')
   if [ "$ARCH" = "" ] && [ "$TEMP_ARCH" != "" ]; then
       ARCH=$TEMP_ARCH
   fi
   VPRINT "UPDATE_DISPLAY_VARIABLES()-ARCH=$ARCH"

   if echo  "$RPMNAME" | egrep -e 'cproc' &> /dev/null; then
        COMP_TYPE="$UNS_STRING_43"
   else
        COMP_TYPE="$UNS_STRING_44"
   fi
   
   # if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
   #         beta="$UNS_STRING_45"
   # else
   #         beta=""
   # fi

   case "$PRODUCT" in
   ipp )
        ICC_IPP_INSTALLED=1
        case "$ARCH" in
           i386 )
               if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                       signon="$UNS_STRING_61"
               else
                       signon="$UNS_STRING_58"
               fi
               ;;
           ia64 )
               if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                       signon="$UNS_STRING_62"
               else
                       signon="$UNS_STRING_59"
               fi
               ;;
           x86_64 )
               if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                       signon="$UNS_STRING_63"
               else
                       signon="$UNS_STRING_60"
               fi
               ;;
           * )
               continue ;;
        esac
        ;;
   tbb )
        ICC_TBB_INSTALLED=1
        case "$ARCH" in
           i386 )
               if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                       signon="$UNS_STRING_73"
               else
                       signon="$UNS_STRING_70"
               fi
               ;;
           ia64 )
               if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                       signon="$UNS_STRING_74"
               else
                       signon="$UNS_STRING_71"
               fi
               ;;
           x86_64 )
               if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                       signon="$UNS_STRING_75"
               else
                       signon="$UNS_STRING_72"
               fi
               ;;
           * )
               continue ;;
        esac
        ;;
   idb )
        # signon="Intel(R) $COMP_TYPE Compiler Professional 11 Debugger"
        signon="Intel(R) $COMP_TYPE $UNS_STRING_48"
	# if fortran then
	if [ "$COMP_TYPE" = "$UNS_STRING_44" ]; then
            IFORT_IDB_INSTALLED=1
            case "$ARCH" in
               i386 )
                   if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                           signon="$UNS_STRING_91"
                   else
                           signon="$UNS_STRING_88"
                   fi
                   ;;
               ia64 )
                   if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                           signon="$UNS_STRING_92"
                   else
                           signon="$UNS_STRING_89"
                   fi
                   ;;
               x86_64 )
                   if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                           signon="$UNS_STRING_93"
                   else
                           signon="$UNS_STRING_90"
                   fi
                   ;;
               * )
                   continue ;;
            esac
	else
            ICC_IDB_INSTALLED=1
            case "$ARCH" in
               i386 )
                   if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                           signon="$UNS_STRING_79"
                   else
                           signon="$UNS_STRING_76"
                   fi
                   ;;
               ia64 )
                   if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                           signon="$UNS_STRING_80"
                   else
                           signon="$UNS_STRING_77"
                   fi
                   ;;
               x86_64 )
                   if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                           signon="$UNS_STRING_81"
                   else
                           signon="$UNS_STRING_78"
                   fi
                   ;;
               * )
                   continue ;;
            esac
	fi
        ;;
   mkl )
        # signon="Intel(R) $COMP_TYPE Compiler Professional 11 MKL"
	# if fortran then
	if [ "$COMP_TYPE" = "$UNS_STRING_44" ]; then
            IFORT_MKL_INSTALLED=1
            case "$ARCH" in
               i386 )
                   if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                           signon="$UNS_STRING_85"
                   else
                           signon="$UNS_STRING_82"
                   fi
                   ;;
               ia64 )
                   if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                           signon="$UNS_STRING_86"
                   else
                           signon="$UNS_STRING_83"
                   fi
                   ;;
               x86_64 )
                   if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                           signon="$UNS_STRING_87"
                   else
                           signon="$UNS_STRING_84"
                   fi
                   ;;
               * )
                   continue ;;
            esac
	else
            ICC_MKL_INSTALLED=1
            case "$ARCH" in
               i386 )
                   if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                           signon="$UNS_STRING_67"
                   else
                           signon="$UNS_STRING_64"
                   fi
                   ;;
               ia64 )
                   if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                           signon="$UNS_STRING_68"
                   else
                           signon="$UNS_STRING_65"
                   fi
                   ;;
               x86_64 )
                   if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                           signon="$UNS_STRING_69"
                   else
                           signon="$UNS_STRING_66"
                   fi
                   ;;
               * )
                   continue ;;
            esac
	fi
        ;;
   cproc${PKGNUM}- | cproc${PKGNUM}e- )
        # signon="Intel(R) Compiler Pro 11 C++ Compiler"
        # signon="$UNS_STRING_50"
        ICC_INSTALLED=1
        case "$ARCH" in
           i386 )
               if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                       signon="$UNS_STRING_97"
               else
                       signon="$UNS_STRING_94"
               fi
               ;;
           ia64 )
               if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                       signon="$UNS_STRING_98"
               else
                       signon="$UNS_STRING_95"
               fi
               ;;
           x86_64 )
               if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                       signon="$UNS_STRING_99"
               else
                       signon="$UNS_STRING_96"
               fi
               ;;
           * )
               continue ;;
        esac
        ;;
   cprof${PKGNUM}- | cprof${PKGNUM}e- )
        # signon="Intel(R) Compiler Pro 11 Fortran Compiler"
        signon="$UNS_STRING_51"
        IFORT_INSTALLED=1
        case "$ARCH" in
           i386 )
               if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                       signon="$UNS_STRING_103"
               else
                       signon="$UNS_STRING_100"
               fi
               ;;
           ia64 )
               if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                       signon="$UNS_STRING_104"
               else
                       signon="$UNS_STRING_101"
               fi
               ;;
           x86_64 )
               if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
                       signon="$UNS_STRING_105"
               else
                       signon="$UNS_STRING_102"
               fi
               ;;
           * )
               continue ;;
        esac
        ;;
   * )
        VPRINT "UPDATE_DISPLAY_VARIABLES() - PRODUCT=<$PRODUCT> no match - "; 
        continue 
   ;;
   esac
   
   # case "$ARCH" in
   # i386 )
   #       signon="$signon $UNS_STRING_52 $beta"
   # ;;
   # ia64 )
   #       signon="$signon $UNS_STRING_53 $beta"
   # ;;
   # x86_64 )
   #       signon="$signon $UNS_STRING_54 $beta"
   # ;;
   # * )
   #       continue ;;
   # esac
   DISPLAY_NAME="$signon"
}


# process all command line arguments
PROCESS_ARGS ()
{
    # --default  and --verbose added added
    VPRINT "PROCESS_ARGS() - SCRIPT_ARGS=$SCRIPT_ARGS"

    for THIS_ARG in $SCRIPT_ARGS
    do
        VPRINT "PROCESS_ARGS() - THIS_ARG=$THIS_ARG"
        case "$THIS_ARG" in
            --nonrpm )
                NONRPM_SWITCH=1
	        ;;
            --default )
                DEFAULT_MODE=1
	        ;;
            --verbose )
                VERBOSE_MODE=1
	        ;;
            --debug )
                VERBOSE_MODE=1
                DEBUG_MODE=1
		# DEBUG mode enabled - debug comments in ENGLISH only
		echo "$UNS_STRING_55"
	        ;;
            * )
                # Unknown option \'$SCRIPT_ARGS\'
		echo "$UNS_STRING_56 \'$SCRIPT_ARGS\'"
                echo
	       exit 1;;
            esac
    done
}

# exit script
TINI_SCRIPT ()
{
    VPRINT "TINI_SCRIPT()"
    exit
}
# ------------------------------------------------------------------------
IS_OS_FEDORA_9 () 
{
	# return 1 for TRUE (OS is Redhat Fedora 9)
	# return 0 for FALSE (OS is NOT Redhat Fedora 9)

   local RELEASE_FILE=/etc/fedora-release
   local RELEASE_CONTENT_A="Fedora"
   local RELEASE_CONTENT_B="release 9"
   local RESULT_A
   local RESULT_B
   if [ -s $RELEASE_FILE ]; then
        RESULT_A=$(grep -i "$RELEASE_CONTENT_A" $RELEASE_FILE)
        RESULT_B=$(grep -i "$RELEASE_CONTENT_B" $RELEASE_FILE)
	if [ "$RESULT_A" != "" ] && [ "$RESULT_B" != "" ]; then
            OS_FEDORA_9=1
	    OS_NAME="Fedora Release 9"
	    # echo "... $OS_NAME detected"
	    return 1
        else
            OS_FEDORA_9=0	
	    # echo -n "."
	    return 0
        fi
   else
       OS_FEDORA_9=0	
       return 0
    fi
}


####
# ----------------------------------------------------
# Uninstallation Starts here.
#-----------------------------------------------------
####

#clear
SCRIPT="$0"
SCRIPT_ARGS="$@"
ARGS_NUM="$#"
SCRIPT_DIR="$(dirname $SCRIPT)"

if [ "$SCRIPT_DIR" = "." ]; then
    SCRIPT_DIR="$(pwd)"
else
    cd $SCRIPT_DIR
    SCRIPT_DIR="$(pwd)"
fi


if [ "$1" = "--verbose" ]; then 
    VERBOSE_MODE=1
    shift
fi

NONRPM_SWITCH=0
DEFAULT_MODE=0
VERBOSE_MODE=0
DEBUG_MODE=0
EP_INSTALLED=0
IFORT_INSTALLED=0
IFORT_IDB_INSTALLED=0
IFORT_MKL_INSTALLED=0
ICC_INSTALLED=0
ICC_IDB_INSTALLED=0
ICC_MKL_INSTALLED=0
ICC_TBB_INSTALLED=0
ICC_IPP_INSTALLED=0
PRESERVE_FORTRAN=0
PRESERVE_ICC=0
INTEL_SDP_PRODUCTS_DB=""

LOCAL_VERSION=1.30
#THIS_PACKAGEID=l_cprof_b_11.0.730
THIS_PACKAGEID=l_cproc_p_11.0.074
PACKAGE_NUMBER=$(echo $THIS_PACKAGEID | cut -f 4 -d_)
PKGNUM=$(echo $PACKAGE_NUMBER | tr -d .)
PKG_TYPE=$(echo $THIS_PACKAGEID | cut -f 2 -d_)
#echo "PACKAGE_NUMBER=$PACKAGE_NUMBER --- PKGNUM=$PKGNUM --- PKG_TYPE=$PKG_TYPE"
## determine whether user is root or not.

RESULT="$(echo $0 | grep uninstall_cprof)"
if [ "$RESULT" != "" ]; then
    LANG_BASE="uninstall_cprof.txt"
else
    RESULT="$(echo $0 | grep uninstall_cproc)"
    if [ "$RESULT" != "" ]; then
        LANG_BASE="uninstall_cproc.txt"
    else
        LANG_BASE="uninstall_idb.txt"
    fi
fi

if [ "$LANG" != "" ]; then
    case $LANG in
        ja_JP.utf-8 | ja_JP.UTF-8)
            LANG_FILE=$SCRIPT_DIR/ja_JP/$LANG_BASE
	    ;;
        en_US.utf-8 | en_US.UTF-8)
            LANG_FILE=$SCRIPT_DIR/en_US/$LANG_BASE
	    ;;
        * )
            LANG_FILE=$SCRIPT_DIR/en_US/$LANG_BASE
	    ;;
    esac
else
    LANG_FILE=$SCRIPT_DIR/en_US/$LANG_BASE
fi

if [ -s "$LANG_FILE" ]; then
    source $LANG_FILE
else
    echo "Internal error: cannot find localization component"
    TINI_SCRIPT
fi

if [ "$UNS_STRING_1" = "" ]; then
    echo "Internal error: localization string management malfunction"
    TINI_SCRIPT
fi

PROCESS_ARGS
IS_USER_ROOT
IS_RPM_PRESENT
GET_FLATFILE_DB_LOCATION
CHECK_LOCAL_UNINSTALL

# if DEFAULT_MODE then remove everything without noise unless error occurs
if [ "$DEFAULT_MODE" = 1 ] ; then
    if [ "$ROOT_USER" = 0 ] ; then
       VPRINT "non-RPM default mode"
       UNINSTALL_ALL_NON_RPM 
       exit 0
    elif  [ ! "$RPM_NOT_FOUND" = 0 ] || [ "$NONRPM_SWITCH" = 1 ]; then
       VPRINT "non-RPM default mode"
       VPRINT  "executing UNINSTALL_ALL_NON_RPM"
       UNINSTALL_ALL_NON_RPM 
       exit 0
    else 
       if [ "$VERBOSE_MODE" = 1 ]; then echo "RPM default mode"; fi
       UNINSTALL_ALL_RPM 
       exit 0
    fi 
    VPRINT "uninstall -  default mode - exiting"
    exit 0
fi    



## If user is not root, perform uninstallation by querying the flat file database.
if [ "$ROOT_USER" = 0 ] ; then
	NON_RPM_BASED_UNINSTALLATION
else
	if  [ ! "$RPM_NOT_FOUND" = 0 ] || [ "$NONRPM_SWITCH" = 1 ]; then
		NON_RPM_BASED_UNINSTALLATION
	else
		RPM_BASED_UNINSTALL_CHOICES
	fi
fi

